@@ -35,7 +35,6 @@
 #include "lang.h"
 #include "types.h"
 #include "protos.h"
-#include "expr.h"
 #include "globals.h"
 #include "err.h"
 #include "md5.h"
@@ -1041,7 +1040,7 @@ static void DoCalendarOneMonth(void)
 	    printf("\"entries\":[\n");
 	}
     }
-    while (WriteCalendarRow()) continue;
+    while (WriteCalendarRow()) /* continue */;
 
     if (PsCal == PSCAL_LEVEL1) {
 	printf("%s\n", PSEND);
@@ -1670,6 +1669,7 @@ static void GenerateCalEntries(int col)
 	    case T_Pop:     r=PopOmitContext(&p);     break;
 	    case T_Push:    r=PushOmitContext(&p);    break;
 	    case T_Preserve: r=DoPreserve(&p);        break;
+            case T_Expr: r = DoExpr(&p);              break;
 	    case T_RemType: if (tok.val == RUN_TYPE) {
 		r=DoRun(&p);
 		break;
@@ -1770,7 +1770,7 @@ static int DoCalRem(ParsePtr p, int col)
     DBufInit(&raw_buf);
 
     /* Parse the trigger date and time */
-    if ( (r=ParseRem(p, &trig, &tim, 1)) ) {
+    if ( (r=ParseRem(p, &trig, &tim)) ) {
 	FreeTrig(&trig);
 	return r;
     }
