@@ -42,8 +42,8 @@
 
 
 /* Convenient macros for closing files */
-#define FCLOSE(fp) (((fp)&&((fp)!=stdin)) ? (fclose(fp),(fp)=NULL) : ((fp)=NULL))
-#define PCLOSE(fp) (((fp)&&((fp)!=stdin)) ? (pclose(fp),(fp)=NULL) : ((fp)=NULL))
+#define FCLOSE(fp) ((((fp)!=stdin)) ? (fclose(fp),(fp)=NULL) : ((fp)=NULL))
+#define PCLOSE(fp) ((((fp)!=stdin)) ? (pclose(fp),(fp)=NULL) : ((fp)=NULL))
 
 /* Define the structures needed by the file caching system */
 typedef struct cache {
@@ -79,6 +79,7 @@ typedef struct {
     int LineNo;
     unsigned int IfFlags;
     int NumIfs;
+    int IfLinenos[IF_NEST];
     long offset;
     CachedLine *CLine;
     int ownedByMe;
@@ -101,13 +102,17 @@ static int CheckSafetyAux (struct stat *statbuf);
 static int PopFile (void);
 static int IncludeCmd(char const *);
 
-void set_cloexec(int fd)
+void set_cloexec(FILE *fp)
 {
     int flags;
-    flags = fcntl(fd, F_GETFD);
-    if (flags >= 0) {
-        flags |= FD_CLOEXEC;
-        fcntl(fd, F_SETFD, flags);
+    int fd;
+    if (fp) {
+        fd = fileno(fp);
+        flags = fcntl(fd, F_GETFD);
+        if (flags >= 0) {
+            flags |= FD_CLOEXEC;
+            fcntl(fd, F_SETFD, flags);
+        }
     }
 }
 
@@ -135,7 +140,7 @@ static void OpenPurgeFile(char const *fname, char const *mode)
     if (!PurgeFP) {
 	fprintf(ErrFp, "Cannot open `%s' for writing: %s\n", DBufValue(&fname_buf), strerror(errno));
     }
-    set_cloexec(fileno(PurgeFP));
+    set_cloexec(PurgeFP);
     DBufFree(&fname_buf);
 }
 
@@ -340,7 +345,7 @@ int OpenFile(char const *fname)
 	}
     } else {
 	fp = fopen(fname, "r");
-        if (fp) set_cloexec(fileno(fp));
+        set_cloexec(fp);
 	if (DebugFlag & DB_TRACE_FILES) {
 	    fprintf(ErrFp, "Reading `%s': Opening file on disk\n", fname);
 	}
@@ -360,7 +365,7 @@ int OpenFile(char const *fname)
 	    if (strcmp(fname, "-")) {
 		fp = fopen(fname, "r");
 		if (!fp || !CheckSafety()) return E_CANT_OPEN;
-                set_cloexec(fileno(fp));
+                set_cloexec(fp);
 		if (PurgeMode) OpenPurgeFile(fname, "w");
 	    } else {
 		fp = stdin;
@@ -522,8 +527,14 @@ static int NextChainedFile(IncludeStruct *i)
 static int PopFile(void)
 {
     IncludeStruct *i;
+    int j;
 
-    if (!Hush && NumIfs) Eprint("%s", ErrMsg[E_MISS_ENDIF]);
+    if (!Hush && NumIfs) {
+        Eprint("%s", ErrMsg[E_MISS_ENDIF]);
+        for (j=NumIfs-1; j >=0; j--) {
+            fprintf(ErrFp, "%s(%d): IF without ENDIF\n", FileName, IfLinenos[j]);
+        }
+    }
     if (!IStackPtr) return E_EOF;
     i = &IStack[IStackPtr-1];
 
@@ -543,6 +554,7 @@ static int PopFile(void)
 
     LineNo = i->LineNo;
     IfFlags = i->IfFlags;
+    memcpy(IfLinenos, i->IfLinenos, IF_NEST);
     NumIfs = i->NumIfs;
     CLine = i->CLine;
     fp = NULL;
@@ -557,7 +569,7 @@ static int PopFile(void)
 	if (strcmp(i->filename, "-")) {
 	    fp = fopen(i->filename, "r");
 	    if (!fp || !CheckSafety()) return E_CANT_OPEN;
-            set_cloexec(fileno(fp));
+            set_cloexec(fp);
 	    if (PurgeMode) OpenPurgeFile(i->filename, "a");
 	} else {
 	    fp = stdin;
@@ -867,6 +879,7 @@ static int IncludeCmd(char const *cmd)
     i->LineNo = LineNo;
     i->NumIfs = NumIfs;
     i->IfFlags = IfFlags;
+    memcpy(i->IfLinenos, IfLinenos, IF_NEST);
     i->CLine = CLine;
     i->offset = -1L;
     i->chain = NULL;
@@ -969,6 +982,7 @@ int IncludeFile(char const *fname)
     i->LineNo = LineNo;
     i->NumIfs = NumIfs;
     i->IfFlags = IfFlags;
+    memcpy(i->IfLinenos, IfLinenos, IF_NEST);
     i->CLine = CLine;
     i->offset = -1L;
     i->chain = NULL;
