@@ -78,9 +78,12 @@ EXTERN  INIT(   int     ExpressionEvaluationDisabled, 0);
 EXTERN  INIT(   int     ExpressionEvaluationTimeLimit, 0);
 EXTERN  INIT(   volatile sig_atomic_t ExpressionTimeLimitExceeded, 0);
 EXTERN  INIT(   int     IgnoreOnce, 0);
-EXTERN  INIT(   int     SortByTime, 0);
-EXTERN  INIT(   int     SortByDate, 0);
-EXTERN	INIT(	int	SortByPrio, 0);
+EXTERN  INIT(   char const *OnceFile, NULL);
+EXTERN  INIT(   int     OnceDate, -1);
+EXTERN  INIT(   int     ProcessedOnce, 0);
+EXTERN  INIT(   int     SortByTime, SORT_NONE);
+EXTERN  INIT(   int     SortByDate, SORT_NONE);
+EXTERN	INIT(	int	SortByPrio, SORT_NONE);
 EXTERN  INIT(   int     UntimedBeforeTimed, 0);
 EXTERN	INIT(	int	DefaultPrio, NO_PRIORITY);
 EXTERN  INIT(   int     SysTime, -1);
