@@ -14,15 +14,14 @@
 #include "config.h"
 
 #include <stdio.h>
-
+#include <string.h>
 #include <stdlib.h>
 #include "types.h"
 #include "protos.h"
 #include "globals.h"
 #include "err.h"
-#include "expr.h"
 
-static int BexistsIntArray (int array[], int num, int key);
+static int BexistsIntArray (int const array[], int num, int key);
 static void InsertIntoSortedArray (int *array, int num, int key);
 
 /* Arrays for the global omits */
@@ -37,6 +36,8 @@ int NumFullOmits, NumPartialOmits;
 /* The structure for saving and restoring OMIT contexts */
 typedef struct omitcontext {
     struct omitcontext *next;
+    char *filename;
+    int lineno;
     int numfull, numpart;
     int *fullsave;
     int *partsave;
@@ -79,19 +80,25 @@ int DoClear(ParsePtr p)
 /*                                                             */
 /*  Free all the memory used by saved OMIT contexts.           */
 /*  As a side effect, return the number of OMIT contexts       */
-/*  destroyed.                                                 */
+/*  destroyed.  If print_unmatched is true, print an error for */
+/*  each undestroyed OMIT contect                              */
 /*                                                             */
 /***************************************************************/
-int DestroyOmitContexts(void)
+int DestroyOmitContexts(int print_unmatched)
 {
     OmitContext *c = SavedOmitContexts;
     OmitContext *d;
     int num = 0;
 
     while (c) {
+        if (print_unmatched) {
+            Wprint("Unmatched PUSH-OMIT-CONTEXT at %s(%d)",
+                   c->filename, c->lineno);
+        }
 	num++;
 	if (c->fullsave) free(c->fullsave);
 	if (c->partsave) free(c->partsave);
+        if (c->filename) free(c->filename);
 	d = c->next;
 	free(c);
 	c = d;
@@ -116,16 +123,28 @@ int PushOmitContext(ParsePtr p)
     context = NEW(OmitContext);
     if (!context) return E_NO_MEM;
 
+    if (FileName) {
+        context->filename = StrDup(FileName);
+    } else {
+        context->filename = StrDup("");
+    }
+    if (!context->filename) {
+        free(context);
+        return E_NO_MEM;
+    }
+    context->lineno = LineNo;
     context->numfull = NumFullOmits;
     context->numpart = NumPartialOmits;
     context->weekdaysave = WeekdayOmits;
     context->fullsave = malloc(NumFullOmits * sizeof(int));
     if (NumFullOmits && !context->fullsave) {
+        free(context->filename);
 	free(context);
 	return E_NO_MEM;
     }
     context->partsave = malloc(NumPartialOmits * sizeof(int));
     if (NumPartialOmits && !context->partsave) {
+        free(context->filename);
 	free(context->fullsave);
 	free(context);
 	return E_NO_MEM;
@@ -175,6 +194,7 @@ int PopOmitContext(ParsePtr p)
 /* Free memory used by the saved context */
     if (c->partsave) free(c->partsave);
     if (c->fullsave) free(c->fullsave);
+    if (c->filename) free(c->filename);
     free(c);
 
     return VerifyEoln(p);
@@ -251,7 +271,7 @@ int IsOmitted(int dse, int localomit, char const *omitfunc, int *omit)
 /*  element is found, 0 otherwise.                             */
 /*                                                             */
 /***************************************************************/
-static int BexistsIntArray(int array[], int num, int key)
+static int BexistsIntArray(int const array[], int num, int key)
 {
     int top=num-1, bot=0, mid;
 
